package Catmandu::EuropePMC;


our $VERSION = '0.16';

1;
__END__

=encoding utf-8

=head1 NAME

Catmandu::EuropePMC - A bundle of Catmandu modules for working with data from EuropePMC

=head1 STATUS

=begin HTML

<p>
<a href="https://travis-ci.org/LibreCat/Catmandu-EuropePMC"><img src="https://travis-ci.org/LibreCat/Catmandu-EuropePMC.svg?branch=master" alt="build status" /></a>
<a href="https://coveralls.io/r/LibreCat/Catmandu-EuropePMC"><img src="https://coveralls.io/repos/LibreCat/Catmandu-EuropePMC/badge.png?branch=master" alt="coverage status" /></a>
<a href="http://cpants.cpanauthors.org/dist/Catmandu-EuropePMC"><img src="http://cpants.cpanauthors.org/dist/Catmandu-EuropePMC.png" alt="kwalitee score" /></a>
</p>

=end HTML

=head1 MODULES

=over

=item *

L<Catmandu::Importer::EuropePMC>

=item *

L<Catmandu::Fix::epmc_dbLinks>

=back

=head1 AUTHOR

Vitali Peil

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Vitali Peil.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

=cut
